darkhistory.spec.transferfunclist.TransferFuncList — DarkHistory documentation

# darkhistory.spec.transferfunclist.TransferFuncList

class `darkhistory.spec.transferfunclist.` `TransferFuncList`(tflist)

  List of transfer functions.

  Parameters: | tflist : list of TransFuncAtRedshift or TransFuncAtEnergy
  Attributes: | tflist : list of TransFuncAtRedshift or TransFuncAtEnergy List of transfer functions that is part of this class. tftype : {‘rs’, ‘in_eng’} Type of transfer functions in the list: ‘rs’ for TransFuncAtRedshift, ‘in_eng’ for TransFuncAtEnergy rs : ndarray Redshift abscissa of the transfer functions. in_eng : ndarray Injection energy abscissa of the transfer functions. spec_type : {‘N’, ‘dNdE’} The type of spectra stored in the transfer functions. dlnz : float The d ln(1+z) step for the transfer functions.

  Methods

  `at_val`(axis, new_val[, bounds_error, fill_value]) | Returns the transfer functions at the new abscissa.
  `coarsen`(dlnz_factor[, delete_tfs, …]) | Coarsens the new transfer function with larger dlnz.
  `transpose`() | Transposes the list of transfer functions.

  `__init__`(tflist)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(tflist) | Initialize self.
  `at_val`(axis, new_val[, bounds_error, fill_value]) | Returns the transfer functions at the new abscissa.
  `coarsen`(dlnz_factor[, delete_tfs, …]) | Coarsens the new transfer function with larger dlnz.
  `transpose`() | Transposes the list of transfer functions.

  Attributes

  `dlnz` |
  `eng` |
  `grid_vals` |
  `in_eng` |
  `rs` |
  `tflist` |
  `tftype` |

#### Previous topic

darkhistory.spec.transferfunclist.TransferFuncInterps

#### Next topic

darkhistory.spec.transferfunclist.TransferFuncListArray

### This Page

Show Source